netapp_ontap.resources.switch_port API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.switch_port`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

This API can be used to get the port information for an ethernet switch used in a cluster or storage networks. This API supports GET only. The GET operation returns a list of ports with status and configuration information.

## Examples

### Retrieving the ports for ethernet switches

The following example retrieves the ethernet switch ports for all the ethernet switches used for cluster and/or storage networks. Note that if the fields=* parameter is not specified, the fields in-octets, in-errors, in-discards, out-octets, out-errors, out-discards, interface-number, unique-name, mac-address are not returned. Filters can be added on the fields to limit the results.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import SwitchPort

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(SwitchPort.get_collection()))

Try it out

    [
        SwitchPort(
            {
                "vlan_id": [1, 17, 18, 92],
                "identity": {"number": 1, "index": 436207616, "name": "Ethernet1/1"},
                "speed": 100000,
                "statistics": {
                    "transmit_raw": {"errors": 0, "discards": 0, "packets": 206717534},
                    "receive_raw": {"errors": 0, "discards": 0, "packets": 1616467751},
                },
                "_links": {
                    "self": {
                        "href": "/api/network/ethernet/switch/ports/RTP-CS01-510R11%28FOC22092K12%29/Ethernet1%2F1/436207616"
                    }
                },
                "state": "up",
                "duplex_type": "full_duplex",
                "mtu": 9216,
                "mac_address": "00:be:75:ae:2a:d4",
                "remote_port": {
                    "name": "e3a",
                    "device": {
                        "node": {
                            "uuid": "54c0f036-8a3a-11ea-893d-00a098fd726d",
                            "name": "stiA400-311",
                            "_links": {
                                "self": {
                                    "href": "/api/cluster/nodes/54c0f036-8a3a-11ea-893d-00a098fd726d"
                                }
                            },
                        }
                    },
                    "mtu": 9000,
                },
                "switch": {
                    "_links": {
                        "self": {
                            "href": "/api/network/ethernet/switches/RTP-CS01-510R11(FOC22092K12)"
                        }
                    },
                    "name": "RTP-CS01-510R11(FOC22092K12)",
                },
                "isl": False,
                "configured": "up",
            }
        ),
        SwitchPort(
            {
                "vlan_id": [1, 17, 18, 92],
                "identity": {"number": 11, "index": 436212736, "name": "Ethernet1/11"},
                "speed": 100000,
                "statistics": {
                    "transmit_raw": {"errors": 0, "discards": 0, "packets": 0},
                    "receive_raw": {"errors": 0, "discards": 0, "packets": 0},
                },
                "_links": {
                    "self": {
                        "href": "/api/network/ethernet/switch/ports/RTP-CS01-510R11%28FOC22092K12%29/Ethernet1%2F11/436212736"
                    }
                },
                "state": "down",
                "duplex_type": "unknown",
                "mtu": 9216,
                "mac_address": "00be75ae2afc",
                "switch": {
                    "_links": {
                        "self": {
                            "href": "/api/network/ethernet/switches/RTP-CS01-510R11(FOC22092K12)"
                        }
                    },
                    "name": "RTP-CS01-510R11(FOC22092K12)",
                },
                "isl": False,
                "configured": "up",
            }
        ),
        SwitchPort(
            {
                "vlan_id": [1, 30],
                "identity": {"number": 10, "index": 436212224, "name": "Ethernet1/10"},
                "speed": 100000,
                "statistics": {
                    "transmit_raw": {"errors": 0, "discards": 0, "packets": 2429595607},
                    "receive_raw": {"errors": 0, "discards": 0, "packets": 332013844},
                },
                "_links": {
                    "self": {
                        "href": "/api/network/ethernet/switch/ports/RTP-SS01-510R10%28FOC22170DFR%29/Ethernet1%2F10/436212224"
                    }
                },
                "state": "up",
                "duplex_type": "full_duplex",
                "mtu": 9216,
                "mac_address": "00fcbaead548",
                "remote_port": {
                    "name": "e0a",
                    "device": {
                        "shelf": {
                            "name": "SHFFG1828000004:B",
                            "uid": "12439000444923584512",
                        }
                    },
                    "mtu": 9000,
                },
                "switch": {
                    "_links": {
                        "self": {
                            "href": "/api/network/ethernet/switches/RTP-SS01-510R10(FOC22170DFR)"
                        }
                    },
                    "name": "RTP-SS01-510R10(FOC22170DFR)",
                },
                "isl": False,
                "configured": "up",
            }
        ),
    ]

### Retrieving a ports on an ethernet switch

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import SwitchPort

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = SwitchPort(
            switch="RTP-SS02-510R10(FOC22131U6T)",
            **{"identity.index": "436211712", "identity.name": "Ethernet1/9"}
        )
        resource.get()
        print(resource)

Try it out

    SwitchPort(
        {
            "vlan_id": [1, 30],
            "identity": {"number": 9, "index": 436211712, "name": "Ethernet1/9"},
            "speed": 100000,
            "statistics": {
                "transmit_raw": {"errors": 0, "discards": 0, "packets": 337898026},
                "receive_raw": {"errors": 0, "discards": 0, "packets": 4012559315},
            },
            "_links": {
                "self": {
                    "href": "/api/network/ethernet/switch/ports/RTP-SS02-510R10%28FOC22131U6T%29/Ethernet1%2F9/436211712"
                }
            },
            "state": "up",
            "duplex_type": "full_duplex",
            "mtu": 9216,
            "mac_address": "00fcbaea7228",
            "remote_port": {
                "name": "e0b",
                "device": {
                    "shelf": {"name": "SHFFG1828000004:A", "uid": "12439000444923584512"}
                },
                "mtu": 9000,
            },
            "switch": {
                "_links": {
                    "self": {
                        "href": "/api/network/ethernet/switches/RTP-SS02-510R10(FOC22131U6T)"
                    }
                },
                "name": "RTP-SS02-510R10(FOC22131U6T)",
            },
            "isl": False,
            "configured": "up",
        }
    )

## Classes

`class SwitchPort (*args, **kwargs)`

  Ethernet Switch Port REST API

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves the ethernet switch ports.

    ### Related ONTAP commands

    - `system switch ethernet interface show`

    ### Learn more

    - `DOC /network/ethernet/switch/ports`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves the ethernet switch ports.

    ### Related ONTAP commands

    - `system switch ethernet interface show`

    ### Learn more

    - `DOC /network/ethernet/switch/ports`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves the ethernet switch ports.

    ### Related ONTAP commands

    - `system switch ethernet interface show`

    ### Learn more

    - `DOC /network/ethernet/switch/ports`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  ### Methods

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves an ethernet switch port.

    ### Related ONTAP commands

    - `system switch ethernet interface show`

    ### Learn more

    - `DOC /network/ethernet/switch/ports`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class SwitchPortSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SwitchPort object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `configured GET`

    Administrative Status.

    Valid choices:

    - down
    - testing
    - up
  `duplex_type GET`

    Duplex Settings.

    Valid choices:

    - full_duplex
    - half_duplex
    - unknown
  `identity GET POST PATCH`

    The identity field of the switch_port.

  `isl GET`

    Is configured as an ISL link.

  `links GET`

    The links field of the switch_port.

  `mac_address GET`

    MAC Address.

  `mtu GET`

    MTU.

  `remote_port GET POST PATCH`

    The remote_port field of the switch_port.

  `speed GET`

    Interface Speed(Mbps)

  `state GET`

    Operational Status.

    Valid choices:

    - dormant
    - down
    - lower_layer_down
    - not_present
    - testing
    - unknown
    - up
  `statistics GET`

    The statistics field of the switch_port.

  `switch GET POST PATCH`

    The switch field of the switch_port.

  `type GET`

    Interface Type.

    Valid choices:

    - ethernetcsmacd
    - fastetherfx
    - fibrechannel
    - gigabitethernet
    - ieee8023adlag
    - other
    - propvirtual
    - softwareloopback
    - tunnel
  `vlan_id GET POST PATCH`

    The vlan_id field of the switch_port.